@@ -28,21 +28,10 @@
 
 #include <gsp-app.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
 #define GSP_TYPE_APP_MANAGER            (gsp_app_manager_get_type ())
-#define GSP_APP_MANAGER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GSP_TYPE_APP_MANAGER, GspAppManager))
-#define GSP_APP_MANAGER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GSP_TYPE_APP_MANAGER, GspAppManagerClass))
-#define GSP_IS_APP_MANAGER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GSP_TYPE_APP_MANAGER))
-#define GSP_IS_APP_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GSP_TYPE_APP_MANAGER))
-#define GSP_APP_MANAGER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GSP_TYPE_APP_MANAGER, GspAppManagerClass))
-
-typedef struct _GspAppManager        GspAppManager;
-typedef struct _GspAppManagerClass   GspAppManagerClass;
-
-typedef struct _GspAppManagerPrivate GspAppManagerPrivate;
+G_DECLARE_DERIVABLE_TYPE (GspAppManager, gsp_app_manager, GSP, APP_MANAGER, GObject)
 
 struct _GspAppManagerClass
 {
@@ -54,14 +43,7 @@ struct _GspAppManagerClass
                           GspApp        *app);
 };
 
-struct _GspAppManager
-{
-        GObject parent_instance;
-
-        GspAppManagerPrivate *priv;
-};
-
-GType           gsp_app_manager_get_type               (void);
+GType           gsp_app_manager_get_type               (void) G_GNUC_CONST;
 
 GspAppManager  *gsp_app_manager_get                    (void);
 
@@ -78,8 +60,6 @@ const char     *gsp_app_manager_get_dir                (GspAppManager *manager,
 void            gsp_app_manager_add                    (GspAppManager *manager,
                                                         GspApp        *app);
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif /* __GSP_APP_MANAGER_H */
