@@ -43,16 +43,13 @@
 #define CK_SEAT_INTERFACE    "org.freedesktop.ConsoleKit.Seat"
 #define CK_SESSION_INTERFACE "org.freedesktop.ConsoleKit.Session"
 
-#define GSM_CONSOLEKIT_GET_PRIVATE(o)                                   \
-        (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_CONSOLEKIT, GsmConsolekitPrivate))
-
-struct _GsmConsolekitPrivate
+typedef struct
 {
         DBusGConnection *dbus_connection;
         DBusGProxy      *bus_proxy;
         DBusGProxy      *ck_proxy;
         guint32          is_connected : 1;
-};
+} GsmConsolekitPrivate;
 
 enum {
         PROP_0,
@@ -83,7 +80,7 @@ static void     gsm_consolekit_on_name_owner_changed (DBusGProxy        *bus_pro
                                                       const char        *new_owner,
                                                       GsmConsolekit   *manager);
 
-G_DEFINE_TYPE (GsmConsolekit, gsm_consolekit, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GsmConsolekit, gsm_consolekit, G_TYPE_OBJECT);
 
 static void
 gsm_consolekit_get_property (GObject    *object,
@@ -92,11 +89,14 @@ gsm_consolekit_get_property (GObject    *object,
                              GParamSpec *pspec)
 {
         GsmConsolekit *manager = GSM_CONSOLEKIT (object);
+        GsmConsolekitPrivate *priv;
+
+        priv = gsm_consolekit_get_instance_private (manager);
 
         switch (prop_id) {
         case PROP_IS_CONNECTED:
                 g_value_set_boolean (value,
-                                     manager->priv->is_connected);
+                                     priv->is_connected);
                 break;
 
         default:
@@ -148,7 +148,6 @@ gsm_consolekit_class_init (GsmConsolekitClass *manager_class)
                               G_TYPE_NONE,
                               3, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_POINTER);
 
-        g_type_class_add_private (manager_class, sizeof (GsmConsolekitPrivate));
 }
 
 static DBusHandlerResult
@@ -177,64 +176,66 @@ gsm_consolekit_ensure_ck_connection (GsmConsolekit  *manager,
 {
         GError  *connection_error;
         gboolean is_connected;
+        GsmConsolekitPrivate *priv;
 
         connection_error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
-        if (manager->priv->dbus_connection == NULL) {
+        if (priv->dbus_connection == NULL) {
                 DBusConnection *connection;
 
-                manager->priv->dbus_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM,
-                                                                 &connection_error);
+                priv->dbus_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM,
+                                                        &connection_error);
 
-                if (manager->priv->dbus_connection == NULL) {
+                if (priv->dbus_connection == NULL) {
                         g_propagate_error (error, connection_error);
                         is_connected = FALSE;
                         goto out;
                 }
 
-                connection = dbus_g_connection_get_connection (manager->priv->dbus_connection);
+                connection = dbus_g_connection_get_connection (priv->dbus_connection);
                 dbus_connection_set_exit_on_disconnect (connection, FALSE);
                 dbus_connection_add_filter (connection,
                                             gsm_consolekit_dbus_filter,
                                             manager, NULL);
         }
 
-        if (manager->priv->bus_proxy == NULL) {
-                manager->priv->bus_proxy =
-                        dbus_g_proxy_new_for_name_owner (manager->priv->dbus_connection,
+        if (priv->bus_proxy == NULL) {
+                priv->bus_proxy =
+                        dbus_g_proxy_new_for_name_owner (priv->dbus_connection,
                                                          DBUS_SERVICE_DBUS,
                                                          DBUS_PATH_DBUS,
                                                          DBUS_INTERFACE_DBUS,
                                                          &connection_error);
 
-                if (manager->priv->bus_proxy == NULL) {
+                if (priv->bus_proxy == NULL) {
                         g_propagate_error (error, connection_error);
                         is_connected = FALSE;
                         goto out;
                 }
 
-                dbus_g_proxy_add_signal (manager->priv->bus_proxy,
+                dbus_g_proxy_add_signal (priv->bus_proxy,
                                          "NameOwnerChanged",
                                          G_TYPE_STRING,
                                          G_TYPE_STRING,
                                          G_TYPE_STRING,
                                          G_TYPE_INVALID);
 
-                dbus_g_proxy_connect_signal (manager->priv->bus_proxy,
+                dbus_g_proxy_connect_signal (priv->bus_proxy,
                                              "NameOwnerChanged",
                                              G_CALLBACK (gsm_consolekit_on_name_owner_changed),
                                              manager, NULL);
         }
 
-        if (manager->priv->ck_proxy == NULL) {
-                manager->priv->ck_proxy =
-                        dbus_g_proxy_new_for_name_owner (manager->priv->dbus_connection,
+        if (priv->ck_proxy == NULL) {
+                priv->ck_proxy =
+                        dbus_g_proxy_new_for_name_owner (priv->dbus_connection,
                                                          "org.freedesktop.ConsoleKit",
                                                          "/org/freedesktop/ConsoleKit/Manager",
                                                          "org.freedesktop.ConsoleKit.Manager",
                                                          &connection_error);
 
-                if (manager->priv->ck_proxy == NULL) {
+                if (priv->ck_proxy == NULL) {
                         g_propagate_error (error, connection_error);
                         is_connected = FALSE;
                         goto out;
@@ -243,27 +244,27 @@ gsm_consolekit_ensure_ck_connection (GsmConsolekit  *manager,
 
         is_connected = TRUE;
 
- out:
-        if (manager->priv->is_connected != is_connected) {
-                manager->priv->is_connected = is_connected;
+out:
+        if (priv->is_connected != is_connected) {
+                priv->is_connected = is_connected;
                 g_object_notify (G_OBJECT (manager), "is-connected");
         }
 
         if (!is_connected) {
-                if (manager->priv->dbus_connection == NULL) {
-                        if (manager->priv->bus_proxy != NULL) {
-                                g_object_unref (manager->priv->bus_proxy);
-                                manager->priv->bus_proxy = NULL;
+                if (priv->dbus_connection == NULL) {
+                        if (priv->bus_proxy != NULL) {
+                                g_object_unref (priv->bus_proxy);
+                                priv->bus_proxy = NULL;
                         }
 
-                        if (manager->priv->ck_proxy != NULL) {
-                                g_object_unref (manager->priv->ck_proxy);
-                                manager->priv->ck_proxy = NULL;
+                        if (priv->ck_proxy != NULL) {
+                                g_object_unref (priv->ck_proxy);
+                                priv->ck_proxy = NULL;
                         }
-                } else if (manager->priv->bus_proxy == NULL) {
-                        if (manager->priv->ck_proxy != NULL) {
-                                g_object_unref (manager->priv->ck_proxy);
-                                manager->priv->ck_proxy = NULL;
+                } else if (priv->bus_proxy == NULL) {
+                        if (priv->ck_proxy != NULL) {
+                                g_object_unref (priv->ck_proxy);
+                                priv->ck_proxy = NULL;
                         }
                 }
         }
@@ -278,13 +279,17 @@ gsm_consolekit_on_name_owner_changed (DBusGProxy    *bus_proxy,
                                       const char    *new_owner,
                                       GsmConsolekit *manager)
 {
+        GsmConsolekitPrivate *priv;
+
         if (name != NULL && strcmp (name, "org.freedesktop.ConsoleKit") != 0) {
                 return;
         }
 
-        if (manager->priv->ck_proxy != NULL) {
-                g_object_unref (manager->priv->ck_proxy);
-                manager->priv->ck_proxy = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
+
+        if (priv->ck_proxy != NULL) {
+                g_object_unref (priv->ck_proxy);
+                priv->ck_proxy = NULL;
         }
 
         gsm_consolekit_ensure_ck_connection (manager, NULL);
@@ -295,8 +300,6 @@ gsm_consolekit_init (GsmConsolekit *manager)
 {
         GError *error;
 
-        manager->priv = GSM_CONSOLEKIT_GET_PRIVATE (manager);
-
         error = NULL;
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
@@ -309,25 +312,28 @@ gsm_consolekit_init (GsmConsolekit *manager)
 static void
 gsm_consolekit_free_dbus (GsmConsolekit *manager)
 {
-        if (manager->priv->bus_proxy != NULL) {
-                g_object_unref (manager->priv->bus_proxy);
-                manager->priv->bus_proxy = NULL;
+        GsmConsolekitPrivate *priv;
+
+        priv = gsm_consolekit_get_instance_private (manager);
+        if (priv->bus_proxy != NULL) {
+                g_object_unref (priv->bus_proxy);
+                priv->bus_proxy = NULL;
         }
 
-        if (manager->priv->ck_proxy != NULL) {
-                g_object_unref (manager->priv->ck_proxy);
-                manager->priv->ck_proxy = NULL;
+        if (priv->ck_proxy != NULL) {
+                g_object_unref (priv->ck_proxy);
+                priv->ck_proxy = NULL;
         }
 
-        if (manager->priv->dbus_connection != NULL) {
+        if (priv->dbus_connection != NULL) {
                 DBusConnection *connection;
-                connection = dbus_g_connection_get_connection (manager->priv->dbus_connection);
+                connection = dbus_g_connection_get_connection (priv->dbus_connection);
                 dbus_connection_remove_filter (connection,
                                                gsm_consolekit_dbus_filter,
                                                manager);
 
-                dbus_g_connection_unref (manager->priv->dbus_connection);
-                manager->priv->dbus_connection = NULL;
+                dbus_g_connection_unref (priv->dbus_connection);
+                priv->dbus_connection = NULL;
         }
 }
 
@@ -421,8 +427,10 @@ gsm_consolekit_attempt_restart (GsmConsolekit *manager)
 {
         gboolean res;
         GError  *error;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -432,7 +440,7 @@ gsm_consolekit_attempt_restart (GsmConsolekit *manager)
                 return;
         }
 
-        res = dbus_g_proxy_call_with_timeout (manager->priv->ck_proxy,
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
                                               "Restart",
                                               INT_MAX,
                                               &error,
@@ -453,8 +461,10 @@ gsm_consolekit_attempt_stop (GsmConsolekit *manager)
 {
         gboolean res;
         GError  *error;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -464,7 +474,7 @@ gsm_consolekit_attempt_stop (GsmConsolekit *manager)
                 return;
         }
 
-        res = dbus_g_proxy_call_with_timeout (manager->priv->ck_proxy,
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
                                               "Stop",
                                               INT_MAX,
                                               &error,
@@ -480,6 +490,69 @@ gsm_consolekit_attempt_stop (GsmConsolekit *manager)
         }
 }
 
+void
+gsm_consolekit_attempt_suspend (GsmConsolekit *manager)
+{
+        gboolean res;
+        GError  *error;
+        GsmConsolekitPrivate *priv;
+
+        error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
+
+        if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
+                g_warning ("Could not connect to ConsoleKit: %s",
+                           error->message);
+                g_error_free (error);
+                return;
+        }
+
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
+                                              "Suspend",
+                                              INT_MAX,
+                                              &error,
+                                              G_TYPE_BOOLEAN, TRUE, /* interactive */
+                                              G_TYPE_INVALID,
+                                              G_TYPE_INVALID);
+
+        if (!res) {
+                g_warning ("Unable to suspend system: %s", error->message);
+                g_error_free (error);
+        }
+}
+
+void
+gsm_consolekit_attempt_hibernate (GsmConsolekit *manager)
+{
+        gboolean res;
+        GError  *error;
+        GsmConsolekitPrivate *priv;
+
+        error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
+
+        if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
+                g_warning ("Could not connect to ConsoleKit: %s",
+                           error->message);
+                g_error_free (error);
+                return;
+        }
+
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
+                                              "Hibernate",
+                                              INT_MAX,
+                                              &error,
+                                              G_TYPE_BOOLEAN, TRUE, /* interactive */
+                                              G_TYPE_INVALID,
+                                              G_TYPE_INVALID);
+
+
+        if (!res) {
+                g_warning ("Unable to hibernate system: %s", error->message);
+                g_error_free (error);
+        }
+}
+
 static gboolean
 get_current_session_id (DBusConnection *connection,
                         char          **session_id)
@@ -523,7 +596,7 @@ get_current_session_id (DBusConnection *connection,
         }
 
         ret = TRUE;
- out:
+out:
         if (message != NULL) {
                 dbus_message_unref (message);
         }
@@ -578,7 +651,7 @@ get_seat_id_for_session (DBusConnection *connection,
         }
 
         ret = TRUE;
- out:
+out:
         if (message != NULL) {
                 dbus_message_unref (message);
         }
@@ -619,8 +692,10 @@ gsm_consolekit_set_session_idle (GsmConsolekit *manager,
         DBusMessage    *reply;
         DBusError       dbus_error;
         DBusMessageIter iter;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -630,7 +705,7 @@ gsm_consolekit_set_session_idle (GsmConsolekit *manager,
         }
 
         session_id = NULL;
-        res = get_current_session_id (dbus_g_connection_get_connection (manager->priv->dbus_connection),
+        res = get_current_session_id (dbus_g_connection_get_connection (priv->dbus_connection),
                                       &session_id);
         if (!res) {
                 goto out;
@@ -652,7 +727,7 @@ gsm_consolekit_set_session_idle (GsmConsolekit *manager,
 
         /* FIXME: use async? */
         dbus_error_init (&dbus_error);
-        reply = dbus_connection_send_with_reply_and_block (dbus_g_connection_get_connection (manager->priv->dbus_connection),
+        reply = dbus_connection_send_with_reply_and_block (dbus_g_connection_get_connection (priv->dbus_connection),
                                                            message,
                                                            -1,
                                                            &dbus_error);
@@ -709,7 +784,7 @@ seat_can_activate_sessions (DBusConnection *connection,
         dbus_message_iter_init (reply, &iter);
         dbus_message_iter_get_basic (&iter, &can_activate);
 
- out:
+out:
         if (message != NULL) {
                 dbus_message_unref (message);
         }
@@ -726,8 +801,10 @@ gsm_consolekit_can_switch_user (GsmConsolekit *manager)
         GError  *error;
         char    *seat_id;
         gboolean ret;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -736,13 +813,13 @@ gsm_consolekit_can_switch_user (GsmConsolekit *manager)
                 return FALSE;
         }
 
-        seat_id = get_current_seat_id (dbus_g_connection_get_connection (manager->priv->dbus_connection));
+        seat_id = get_current_seat_id (dbus_g_connection_get_connection (priv->dbus_connection));
         if (seat_id == NULL || seat_id[0] == '\0') {
                 g_debug ("seat id is not set; can't switch sessions");
                 return FALSE;
         }
 
-        ret = seat_can_activate_sessions (dbus_g_connection_get_connection (manager->priv->dbus_connection),
+        ret = seat_can_activate_sessions (dbus_g_connection_get_connection (priv->dbus_connection),
                                           seat_id);
         g_free (seat_id);
 
@@ -752,31 +829,33 @@ gsm_consolekit_can_switch_user (GsmConsolekit *manager)
 gboolean
 gsm_consolekit_get_restart_privileges (GsmConsolekit *manager)
 {
-	g_signal_emit (G_OBJECT (manager),
-		       signals [PRIVILEGES_COMPLETED],
-		       0, TRUE, TRUE, NULL);
+        g_signal_emit (G_OBJECT (manager),
+                       signals [PRIVILEGES_COMPLETED],
+                       0, TRUE, TRUE, NULL);
 
-	return TRUE;
+        return TRUE;
 }
 
 gboolean
 gsm_consolekit_get_stop_privileges (GsmConsolekit *manager)
 {
-	g_signal_emit (G_OBJECT (manager),
-		       signals [PRIVILEGES_COMPLETED],
-		       0, TRUE, TRUE, NULL);
+        g_signal_emit (G_OBJECT (manager),
+                       signals [PRIVILEGES_COMPLETED],
+                       0, TRUE, TRUE, NULL);
 
-	return TRUE;
+        return TRUE;
 }
 
 gboolean
 gsm_consolekit_can_restart (GsmConsolekit *manager)
 {
         gboolean res;
-	gboolean can_restart;
+        gboolean can_restart;
         GError  *error;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -785,7 +864,7 @@ gsm_consolekit_can_restart (GsmConsolekit *manager)
                 return FALSE;
         }
 
-        res = dbus_g_proxy_call_with_timeout (manager->priv->ck_proxy,
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
                                               "CanRestart",
                                               INT_MAX,
                                               &error,
@@ -797,19 +876,21 @@ gsm_consolekit_can_restart (GsmConsolekit *manager)
                            error->message);
                 g_error_free (error);
                 return FALSE;
-	}
+        }
 
-	return can_restart;
+        return can_restart;
 }
 
 gboolean
 gsm_consolekit_can_stop (GsmConsolekit *manager)
 {
         gboolean res;
-	gboolean can_stop;
+        gboolean can_stop;
         GError  *error;
+        GsmConsolekitPrivate *priv;
 
         error = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
@@ -818,7 +899,7 @@ gsm_consolekit_can_stop (GsmConsolekit *manager)
                 return FALSE;
         }
 
-        res = dbus_g_proxy_call_with_timeout (manager->priv->ck_proxy,
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
                                               "CanStop",
                                               INT_MAX,
                                               &error,
@@ -831,76 +912,158 @@ gsm_consolekit_can_stop (GsmConsolekit *manager)
                            error->message);
                 g_error_free (error);
                 return FALSE;
-	}
+        }
 
-	return can_stop;
+        return can_stop;
+}
+
+gboolean
+gsm_consolekit_can_suspend (GsmConsolekit *manager)
+{
+        gboolean res;
+        gboolean can_suspend;
+        gchar *retval;
+        GError *error = NULL;
+        GsmConsolekitPrivate *priv;
+
+        priv = gsm_consolekit_get_instance_private (manager);
+
+        if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
+                g_warning ("Could not connect to ConsoleKit: %s",
+                           error->message);
+                g_error_free (error);
+                return FALSE;
+        }
+
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
+                                              "CanSuspend",
+                                              INT_MAX,
+                                              &error,
+                                              G_TYPE_INVALID,
+                                              G_TYPE_STRING, &retval,
+                                              G_TYPE_INVALID);
+
+        if (res == FALSE) {
+                g_warning ("Could not make DBUS call: %s",
+                           error->message);
+                g_error_free (error);
+                return FALSE;
+        }
+
+        can_suspend = g_strcmp0 (retval, "yes") == 0 ||
+                      g_strcmp0 (retval, "challenge") == 0;
+
+        g_free (retval);
+        return can_suspend;
+}
+
+gboolean
+gsm_consolekit_can_hibernate (GsmConsolekit *manager)
+{
+        gboolean res;
+        gboolean can_hibernate;
+        gchar *retval;
+        GError *error = NULL;
+        GsmConsolekitPrivate *priv;
+
+        priv = gsm_consolekit_get_instance_private (manager);
+
+        if (!gsm_consolekit_ensure_ck_connection (manager, &error)) {
+                g_warning ("Could not connect to ConsoleKit: %s",
+                           error->message);
+                g_error_free (error);
+                return FALSE;
+        }
+
+        res = dbus_g_proxy_call_with_timeout (priv->ck_proxy,
+                                              "CanHibernate",
+                                              INT_MAX,
+                                              &error,
+                                              G_TYPE_INVALID,
+                                              G_TYPE_STRING, &retval,
+                                              G_TYPE_INVALID);
+
+        if (res == FALSE) {
+                g_warning ("Could not make DBUS call: %s",
+                           error->message);
+                g_error_free (error);
+                return FALSE;
+        }
+
+        can_hibernate = g_strcmp0 (retval, "yes") == 0 ||
+                        g_strcmp0 (retval, "challenge") == 0;
+
+        g_free (retval);
+        return can_hibernate;
 }
 
 gchar *
 gsm_consolekit_get_current_session_type (GsmConsolekit *manager)
 {
         GError *gerror;
-	DBusConnection *connection;
-	DBusError error;
-	DBusMessage *message = NULL;
-	DBusMessage *reply = NULL;
-	gchar *session_id;
-	gchar *ret;
-	DBusMessageIter iter;
-	const char *value;
+        DBusConnection *connection;
+        DBusError error;
+        DBusMessage *message = NULL;
+        DBusMessage *reply = NULL;
+        gchar *session_id;
+        gchar *ret;
+        DBusMessageIter iter;
+        const char *value;
+        GsmConsolekitPrivate *priv;
 
-	session_id = NULL;
-	ret = NULL;
+        session_id = NULL;
+        ret = NULL;
         gerror = NULL;
+        priv = gsm_consolekit_get_instance_private (manager);
 
         if (!gsm_consolekit_ensure_ck_connection (manager, &gerror)) {
                 g_warning ("Could not connect to ConsoleKit: %s",
                            gerror->message);
                 g_error_free (gerror);
-		goto out;
+                goto out;
         }
 
-	connection = dbus_g_connection_get_connection (manager->priv->dbus_connection);
-	if (!get_current_session_id (connection, &session_id)) {
-		goto out;
-	}
+        connection = dbus_g_connection_get_connection (priv->dbus_connection);
+        if (!get_current_session_id (connection, &session_id)) {
+                goto out;
+        }
 
-	dbus_error_init (&error);
-	message = dbus_message_new_method_call (CK_NAME,
-						session_id,
-						CK_SESSION_INTERFACE,
-						"GetSessionType");
-	if (message == NULL) {
-		goto out;
-	}
+        dbus_error_init (&error);
+        message = dbus_message_new_method_call (CK_NAME,
+                                                session_id,
+                                                CK_SESSION_INTERFACE,
+                                                "GetSessionType");
+        if (message == NULL) {
+                goto out;
+        }
 
-	reply = dbus_connection_send_with_reply_and_block (connection,
-							   message,
-							   -1,
-							   &error);
+        reply = dbus_connection_send_with_reply_and_block (connection,
+                                                           message,
+                                                           -1,
+                                                           &error);
 
-	if (reply == NULL) {
-		if (dbus_error_is_set (&error)) {
-			g_warning ("Unable to determine session type: %s", error.message);
-			dbus_error_free (&error);
-		}
-		goto out;
-	}
+        if (reply == NULL) {
+                if (dbus_error_is_set (&error)) {
+                        g_warning ("Unable to determine session type: %s", error.message);
+                        dbus_error_free (&error);
+                }
+                goto out;
+        }
 
-	dbus_message_iter_init (reply, &iter);
-	dbus_message_iter_get_basic (&iter, &value);
-	ret = g_strdup (value);
+        dbus_message_iter_init (reply, &iter);
+        dbus_message_iter_get_basic (&iter, &value);
+        ret = g_strdup (value);
 
 out:
-	if (message != NULL) {
-		dbus_message_unref (message);
-	}
-	if (reply != NULL) {
-		dbus_message_unref (reply);
-	}
-	g_free (session_id);
+        if (message != NULL) {
+                dbus_message_unref (message);
+        }
+        if (reply != NULL) {
+                dbus_message_unref (reply);
+        }
+        g_free (session_id);
 
-	return ret;
+        return ret;
 }
 
 
